@@ -28,6 +28,9 @@
 
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -82,7 +85,9 @@ class NUFloatingIp(NURESTObject):
         self._last_updated_date = None
         self._access_control = None
         self._address = None
+        self._egress_rate_limiter_id = None
         self._embedded_metadata = None
+        self._ingress_rate_limiter_id = None
         self._entity_scope = None
         self._creation_date = None
         self._assigned = None
@@ -95,7 +100,9 @@ class NUFloatingIp(NURESTObject):
         self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="access_control", remote_name="accessControl", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address", remote_name="address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="egress_rate_limiter_id", remote_name="egressRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="embedded_metadata", remote_name="embeddedMetadata", attribute_type=list, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ingress_rate_limiter_id", remote_name="ingressRateLimiterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assigned", remote_name="assigned", attribute_type=bool, is_required=False, is_unique=False)
@@ -108,6 +115,9 @@ class NUFloatingIp(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -228,6 +238,33 @@ class NUFloatingIp(NURESTObject):
         self._address = value
 
     
+    @property
+    def egress_rate_limiter_id(self):
+        """ Get egress_rate_limiter_id value.
+
+            Notes:
+                ID of the Egress Rate Limiter for this FloatingIP.
+
+                
+                This attribute is named `egressRateLimiterID` in VSD API.
+                
+        """
+        return self._egress_rate_limiter_id
+
+    @egress_rate_limiter_id.setter
+    def egress_rate_limiter_id(self, value):
+        """ Set egress_rate_limiter_id value.
+
+            Notes:
+                ID of the Egress Rate Limiter for this FloatingIP.
+
+                
+                This attribute is named `egressRateLimiterID` in VSD API.
+                
+        """
+        self._egress_rate_limiter_id = value
+
+    
     @property
     def embedded_metadata(self):
         """ Get embedded_metadata value.
@@ -255,6 +292,33 @@ class NUFloatingIp(NURESTObject):
         self._embedded_metadata = value
 
     
+    @property
+    def ingress_rate_limiter_id(self):
+        """ Get ingress_rate_limiter_id value.
+
+            Notes:
+                ID of the Ingress Rate Limiter for this FloatingIP.
+
+                
+                This attribute is named `ingressRateLimiterID` in VSD API.
+                
+        """
+        return self._ingress_rate_limiter_id
+
+    @ingress_rate_limiter_id.setter
+    def ingress_rate_limiter_id(self, value):
+        """ Set ingress_rate_limiter_id value.
+
+            Notes:
+                ID of the Ingress Rate Limiter for this FloatingIP.
+
+                
+                This attribute is named `ingressRateLimiterID` in VSD API.
+                
+        """
+        self._ingress_rate_limiter_id = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
