@@ -31,6 +31,9 @@
 from .fetchers import NUDeploymentFailuresFetcher
 
 
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -94,10 +97,11 @@ class NUIngressProfile(NURESTObject):
         self._associated_mac_filter_profile_name = None
         self._associated_sap_ingress_qo_s_profile_id = None
         self._associated_sap_ingress_qo_s_profile_name = None
+        self._customer_id = None
         self._owner = None
         self._external_id = None
         
-        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -113,6 +117,7 @@ class NUIngressProfile(NURESTObject):
         self.expose_attribute(local_name="associated_mac_filter_profile_name", remote_name="associatedMACFilterProfileName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_sap_ingress_qo_s_profile_id", remote_name="associatedSAPIngressQoSProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_sap_ingress_qo_s_profile_name", remote_name="associatedSAPIngressQoSProfileName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="customer_id", remote_name="customerID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
@@ -123,6 +128,9 @@ class NUIngressProfile(NURESTObject):
         self.deployment_failures = NUDeploymentFailuresFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -560,6 +568,33 @@ class NUIngressProfile(NURESTObject):
         self._associated_sap_ingress_qo_s_profile_name = value
 
     
+    @property
+    def customer_id(self):
+        """ Get customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        return self._customer_id
+
+    @customer_id.setter
+    def customer_id(self, value):
+        """ Set customer_id value.
+
+            Notes:
+                The customer ID given to parent enterprise. This is used by Netconf/Config manager.
+
+                
+                This attribute is named `customerID` in VSD API.
+                
+        """
+        self._customer_id = value
+
+    
     @property
     def owner(self):
         """ Get owner value.
