@@ -63,6 +63,8 @@ class NUVsgRedundantPort(NURESTObject):
     
     CONST_PORT_TYPE_NETWORK = "NETWORK"
     
+    CONST_OPERATIONAL_STATE_DOWN = "DOWN"
+    
     CONST_PERMITTED_ACTION_USE = "USE"
     
     CONST_PERMITTED_ACTION_READ = "READ"
@@ -77,9 +79,11 @@ class NUVsgRedundantPort(NURESTObject):
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_OPERATIONAL_STATE_UP = "UP"
+    
     CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
     
-    CONST_STATUS_INITIALIZED = "INITIALIZED"
+    CONST_OPERATIONAL_STATE_INIT = "INIT"
     
     CONST_STATUS_MISMATCH = "MISMATCH"
     
@@ -89,6 +93,8 @@ class NUVsgRedundantPort(NURESTObject):
     
     CONST_STATUS_ORPHAN = "ORPHAN"
     
+    CONST_STATUS_INITIALIZED = "INITIALIZED"
+    
     
 
     def __init__(self, **kwargs):
@@ -111,6 +117,7 @@ class NUVsgRedundantPort(NURESTObject):
         self._vlan_range = None
         self._name = None
         self._last_updated_by = None
+        self._last_updated_date = None
         self._peer_link = None
         self._permitted_action = None
         self._description = None
@@ -120,15 +127,19 @@ class NUVsgRedundantPort(NURESTObject):
         self._port_peer1_id = None
         self._port_peer2_id = None
         self._port_type = None
+        self._operational_state = None
+        self._creation_date = None
         self._use_user_mnemonic = None
         self._user_mnemonic = None
         self._associated_egress_qos_policy_id = None
         self._status = None
+        self._owner = None
         self._external_id = None
         
         self.expose_attribute(local_name="vlan_range", remote_name="VLANRange", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="last_updated_date", remote_name="lastUpdatedDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peer_link", remote_name="peerLink", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -138,10 +149,13 @@ class NUVsgRedundantPort(NURESTObject):
         self.expose_attribute(local_name="port_peer1_id", remote_name="portPeer1ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="port_peer2_id", remote_name="portPeer2ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'NETWORK'])
+        self.expose_attribute(local_name="operational_state", remote_name="operationalState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DOWN', u'INIT', u'UP'])
+        self.expose_attribute(local_name="creation_date", remote_name="creationDate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_egress_qos_policy_id", remote_name="associatedEgressQOSPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'INITIALIZED', u'MISMATCH', u'ORPHAN', u'READY'])
+        self.expose_attribute(local_name="owner", remote_name="owner", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -247,6 +261,33 @@ class NUVsgRedundantPort(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def last_updated_date(self):
+        """ Get last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        return self._last_updated_date
+
+    @last_updated_date.setter
+    def last_updated_date(self, value):
+        """ Set last_updated_date value.
+
+            Notes:
+                Time stamp when this object was last updated.
+
+                
+                This attribute is named `lastUpdatedDate` in VSD API.
+                
+        """
+        self._last_updated_date = value
+
+    
     @property
     def peer_link(self):
         """ Get peer_link value.
@@ -486,6 +527,60 @@ class NUVsgRedundantPort(NURESTObject):
         self._port_type = value
 
     
+    @property
+    def operational_state(self):
+        """ Get operational_state value.
+
+            Notes:
+                Represents Operational State of the Port. Possible values are INIT, UP, DOWN.
+
+                
+                This attribute is named `operationalState` in VSD API.
+                
+        """
+        return self._operational_state
+
+    @operational_state.setter
+    def operational_state(self, value):
+        """ Set operational_state value.
+
+            Notes:
+                Represents Operational State of the Port. Possible values are INIT, UP, DOWN.
+
+                
+                This attribute is named `operationalState` in VSD API.
+                
+        """
+        self._operational_state = value
+
+    
+    @property
+    def creation_date(self):
+        """ Get creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        return self._creation_date
+
+    @creation_date.setter
+    def creation_date(self, value):
+        """ Set creation_date value.
+
+            Notes:
+                Time stamp when this object was created.
+
+                
+                This attribute is named `creationDate` in VSD API.
+                
+        """
+        self._creation_date = value
+
+    
     @property
     def use_user_mnemonic(self):
         """ Get use_user_mnemonic value.
@@ -590,6 +685,29 @@ class NUVsgRedundantPort(NURESTObject):
         self._status = value
 
     
+    @property
+    def owner(self):
+        """ Get owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        return self._owner
+
+    @owner.setter
+    def owner(self, value):
+        """ Set owner value.
+
+            Notes:
+                Identifies the user that has created this object.
+
+                
+        """
+        self._owner = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
